pub struct RwLock<T: ?Sized> { /* private fields */ }Expand description
An async reader-writer lock: .read().await/.write().await yield
the calling task rather than blocking the OS thread while contended.
Implementations
Sourceimpl<T> RwLock<T>
impl<T> RwLock<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume the lock, returning the guarded value.
Sourceimpl<T: ?Sized + Send + Sync> RwLock<T>
impl<T: ?Sized + Send + Sync> RwLock<T>
Sourcepub async fn read(&self) -> RwLockReadGuard<'_, T>
pub async fn read(&self) -> RwLockReadGuard<'_, T>
Acquire a shared read lock, waiting while a writer holds it. Multiple readers may hold the lock concurrently.
Sourcepub async fn write(&self) -> RwLockWriteGuard<'_, T>
pub async fn write(&self) -> RwLockWriteGuard<'_, T>
Acquire the exclusive write lock, waiting while any reader or writer holds it.